@@ -122,7 +122,7 @@ class App:
     # Initialization helper
     # -------------------------------------------------------------------------
 
-    def enableModule(self, module, **kwargs):
+    def enable_module(self, module, **kwargs):
         if module in self._loaded_modules:
             return
 
@@ -139,16 +139,16 @@ class App:
 
         self._loaded_modules.add(module)
 
-    def disableModule(self, module):
-        for key in ["scripts", "styles", "vue_use"]:
-            if key in module.__dict__:
-                for item in module.__dict__[key]:
-                    self[key].remove(item)
+    def reload_app(self):
+        """Used internally to dynamically reload app"""
+        for module in self._loaded_modules:
+            if hasattr(module, "reload_app"):
+                module.reload_app()
 
-        for key in ["state", "serve", "vuetify"]:
-            if key in module.__dict__:
-                for entry in module.__dict__[key]:
-                    del self[key][entry]
+    # will be removed
+    def enableModule(self, module, **kwargs):
+        print("enableModule is deprecated, you should use 'enable_module' instead.")
+        self.enable_module(module, **kwargs)
 
     # -------------------------------------------------------------------------
     # Annotations
@@ -382,7 +382,6 @@ class App:
                 for key in self.serve:
                     endpoints.append(f"{key}={abs_path(self.serve[key], self._root)}")
                 args.fsEndpoints = "|".join(endpoints)
-                print(args.fsEndpoints)
 
             CoreServer.configure(args)
             CoreServer.start_webserver(args)
